@@ -16,7 +16,7 @@
 
 import mock
 
-from tripleo_common import stack_update
+from tripleo_common import _stack_update
 from tripleo_common.tests import base
 
 
@@ -53,14 +53,9 @@ class StackUpdateManagerTest(base.TestCase):
                     mock.MagicMock(
                         event_time='2015-03-25T09:15:04Z',
                         resource_name='Controller-0',
-                        resource_status='CREATE_IN_PROGRESS',
+                        resource_status='UPDATE_IN_PROGRESS',
                         resource_status_reason='UPDATE paused until Hook '
-                                               'pre-update is cleared'),
-                    mock.MagicMock(
-                        event_time='2015-03-25T09:15:02Z',
-                        resource_name='Controller-1',
-                        resource_status='CREATE_COMPLETE',
-                        resource_status_reason=''),
+                                               'pre-update is cleared')
                 ]
             else:
                 return [
@@ -71,7 +66,7 @@ class StackUpdateManagerTest(base.TestCase):
                 ]
 
         self.heatclient.events.list.side_effect = return_events
-        self.stack_update_manager = stack_update.StackUpdateManager(
+        self.stack_update_manager = _stack_update.StackUpdateManager(
             self.heatclient, self.novaclient, self.stack, 'pre-update')
 
     def test_get_status(self):
@@ -95,14 +90,6 @@ class StackUpdateManagerTest(base.TestCase):
         self.assertEqual(good, [])
         self.assertEqual(bad, ['resource_id'])
 
-    def test_cancel(self):
-        self.stack_update_manager.cancel()
-        self.heatclient.actions.cancel_update.assert_called_once_with('123')
-        self.heatclient.resources.signal.assert_called_once_with(
-            stack_id='123',
-            resource_name='logical_id',
-            data={'unset_hook': 'pre-update'})
-
     def test_intput_to_refs_regexp(self):
         result = self.stack_update_manager._input_to_refs(
             'instance_name.*', ['instance_id'])
@@ -112,3 +99,44 @@ class StackUpdateManagerTest(base.TestCase):
         result = self.stack_update_manager._input_to_refs(
             ']].*', ['instance_id'])
         self.assertEqual(result, [])
+
+    def test_get_servers(self):
+        self.stack_update_manager._get_servers()
+        self.novaclient.servers.list.assert_called()
+
+    def test_get_servers_deployed_server(self):
+        self.novaclient.servers.list.return_value = []
+        self.heatclient.resources.list.return_value = [
+            mock.MagicMock(
+                links=[{'rel': 'stack',
+                        'href': 'http://192.0.2.1:8004/v1/'
+                                'a959ac7d6a4a475daf2428df315c41ef/'
+                                'stacks/overcloud/123'}],
+                logical_resource_id='logical_id',
+                physical_resource_id='controller_resource_id',
+                type='OS::Heat::DeployedServer'
+            ),
+            mock.MagicMock(
+                links=[{'rel': 'stack',
+                        'href': 'http://192.0.2.1:8004/v1/'
+                                'a959ac7d6a4a475daf2428df315c41ef/'
+                                'stacks/overcloud/123'}],
+                logical_resource_id='logical_id',
+                physical_resource_id='compute_resource_id',
+                type='OS::Heat::DeployedServer'
+            )
+        ]
+        self.heatclient.stacks.get.side_effect = [
+            mock.MagicMock(
+                outputs=[{'output_key': 'name',
+                          'output_value': 'overcloud-controller-0'}]),
+            mock.MagicMock(
+                outputs=[{'output_key': 'name',
+                          'output_value': 'overcloud-compute-0'}]),
+        ]
+
+        servers = self.stack_update_manager._get_servers()
+        self.assertEqual(servers[0].name, 'overcloud-controller-0')
+        self.assertEqual(servers[0].id, 'controller_resource_id')
+        self.assertEqual(servers[1].name, 'overcloud-compute-0')
+        self.assertEqual(servers[1].id, 'compute_resource_id')
